You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2010/10/20 17:59:24 UTC

svn commit: r1025622 - in /subversion/trunk/subversion/bindings/ctypes-python/csvn: repos.py wc.py

Author: julianfoad
Date: Wed Oct 20 15:59:23 2010
New Revision: 1025622

URL: http://svn.apache.org/viewvc?rev=1025622&view=rev
Log:
* subversion/bindings/ctypes-python/csvn/repos.py,
  subversion/bindings/ctypes-python/csvn/wc.py
    Fix typos in comments.

Modified:
    subversion/trunk/subversion/bindings/ctypes-python/csvn/repos.py
    subversion/trunk/subversion/bindings/ctypes-python/csvn/wc.py

Modified: subversion/trunk/subversion/bindings/ctypes-python/csvn/repos.py
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/ctypes-python/csvn/repos.py?rev=1025622&r1=1025621&r2=1025622&view=diff
==============================================================================
--- subversion/trunk/subversion/bindings/ctypes-python/csvn/repos.py (original)
+++ subversion/trunk/subversion/bindings/ctypes-python/csvn/repos.py Wed Oct 20 15:59:23 2010
@@ -324,7 +324,7 @@ class RemoteRepository(object):
     def set_log_func(self, log_func):
         """Register a callback to get a log message for commit and
         commit-like operations. LOG_FUNC should take an array as an argument,
-        which holds the files to be commited. It should return a list of the
+        which holds the files to be committed. It should return a list of the
         form [LOG, FILE] where LOG is a log message and FILE is the temporary
         file, if one was created instead of a log message. If LOG is None,
         the operation will be canceled and FILE will be treated as the
@@ -408,7 +408,7 @@ class LocalRepository(object):
           ... absent, then we return svn_node_none.
           ... a regular file, then we return svn_node_file.
           ... a directory, then we return svn_node_dir
-          ... unknown, then we return svn_node_unknowna
+          ... unknown, then we return svn_node_unknown
         """
         assert(not encoded)
         root = self.fs.root(rev=rev, pool=self.iterpool)

Modified: subversion/trunk/subversion/bindings/ctypes-python/csvn/wc.py
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/ctypes-python/csvn/wc.py?rev=1025622&r1=1025621&r2=1025622&view=diff
==============================================================================
--- subversion/trunk/subversion/bindings/ctypes-python/csvn/wc.py (original)
+++ subversion/trunk/subversion/bindings/ctypes-python/csvn/wc.py Wed Oct 20 15:59:23 2010
@@ -30,8 +30,8 @@ class WC(object):
 
         Keyword arguments:
         path -- path to the working copy (default current working directory)
-        user -- object implementingthe user interface representing the user
-            performing the operatio (defaults to an instance of the User class)
+        user -- object implementing the user interface representing the user
+            performing the operation (defaults to an instance of the User class)
         """
         if user is None:
             user = User()
@@ -238,7 +238,7 @@ class WC(object):
     def set_progress_func(self, progress_func):
         """Setup a callback for network progress information.
 
-        This callback should accept two intergers, being the number of bytes
+        This callback should accept two integers, being the number of bytes
         sent and the number of bytes to send.
 
         Keyword arguments:
@@ -428,7 +428,7 @@ class WC(object):
         return props
 
     def propget(self, propname, target="", recurse=True):
-        """Get the the value of propname for target.
+        """Get the value of propname for target.
 
         Returns a hash the keys of which are file paths and the values are the
         value of PROPNAME for the corresponding file. The values of the hash
@@ -477,7 +477,7 @@ class WC(object):
         """Get the status on path using callback to status.
 
         The status callback (which can be set when this method is called or
-        earlier) wil be called for each item.
+        earlier) will be called for each item.
 
         Keyword arguments:
         path -- items to get status for (defaults to WC root)
@@ -585,8 +585,8 @@ class WC(object):
         """Register a callback to get a log message for commit and commit-like
         operations.
 
-        LOG_FUNC should take an array as an argument,vwhich holds the files to
-        be commited. It should return a list of thevform [LOG, FILE] where LOG
+        LOG_FUNC should take an array as an argument, which holds the files to
+        be committed. It should return a list of the form [LOG, FILE] where LOG
         is a log message and FILE is the temporary file, if one was created
         instead of a log message. If LOG is None, the operation will be
         canceled and FILE will be treated as the temporary file holding the
@@ -615,9 +615,9 @@ class WC(object):
         """Commit changes in the working copy.
 
         Keyword arguments:
         paths -- list of paths that should be commited (defaults to WC root)
         recurse -- if True, the contents of directories to be committed will
             also be commited (default True)
         keep_locks -- if True, locks will not be released during commit
             (default False)"""
         commit_info = POINTER(svn_commit_info_t)()
@@ -702,9 +702,9 @@ class WC(object):
         self.iterpool.clear()
 
     def relocate(self, from_url, to_url, dir="", recurse=True):
-        """Modify a working copy directory, changing repository URLs. that begin with FROM_URL to begin with
-        TO_URL instead, recursing into subdirectories if RECURSE is True
-        (True by default).
+        """Modify a working copy directory, changing repository URLs that begin
+        with FROM_URL to begin with TO_URL instead, recursing into
+        subdirectories if RECURSE is True (True by default).
 
         Keyword arguments:
         from_url -- url to be replaced, if this url is matched at the beginning
@@ -615,9 +615,9 @@ class WC(object):
 
         Keyword arguments:
-        paths -- list of paths that should be commited (defaults to WC root)
+        paths -- list of paths that should be committed (defaults to WC root)
         recurse -- if True, the contents of directories to be committed will
@@ -615,9 +615,9 @@ class WC(object):
         recurse -- if True, the contents of directories to be committed will
-            also be commited (default True)
+            also be committed (default True)
         keep_locks -- if True, locks will not be released during commit
             (default False)"""